@@ -18,7 +18,7 @@ from base64 import b64encode
 from lollypop.information_store import InformationStore
 from lollypop.define import App, GOOGLE_API_ID, Type
 from lollypop.define import SPOTIFY_CLIENT_ID, SPOTIFY_SECRET
-from lollypop.utils import get_network_available
+from lollypop.utils import get_network_available, noaccents
 from lollypop.logger import Logger
 from lollypop.helper_task import TaskHelper
 
@@ -43,18 +43,18 @@ class Downloader:
             Download album artwork
             @param album id as int
         """
-        if album_id in self.__albums_history:
+        if album_id in self.__albums_history or\
+                not get_network_available("DATA"):
             return
-        if get_network_available():
-            self.__albums_queue.append(album_id)
-            if not self.__in_albums_download:
-                App().task_helper.run(self.__cache_albums_art)
+        self.__albums_queue.append(album_id)
+        if not self.__in_albums_download:
+            App().task_helper.run(self.__cache_albums_art)
 
     def cache_artists_info(self):
         """
             Cache info for all artists
         """
-        if self.__cache_artists_running:
+        if self.__cache_artists_running or not get_network_available("DATA"):
             return
         self.__cache_artists_running = True
         App().task_helper.run(self.__cache_artists_artwork)
@@ -79,6 +79,8 @@ class Downloader:
             @param content as bytes
             @return [urls as string]
         """
+        if not get_network_available("GOOGLE"):
+            return []
         uris = []
         try:
             decode = json.loads(content.decode("utf-8"))
@@ -89,7 +91,13 @@ class Downloader:
         except Exception as e:
             Logger.error("Downloader::get_google_artwork(): %s, %s" %
                          (e, decode))
-        return uris or None
+        return uris
+
+    def reset_history(self):
+        """
+            Reset download history
+        """
+        self.__albums_history = []
 
 #######################
 # PROTECTED           #
@@ -100,7 +108,7 @@ class Downloader:
             @param artist as str
             @return uri as str
         """
-        if App().lastfm is not None:
+        if get_network_available("LASTFM") and App().lastfm is not None:
             return App().lastfm.get_artist_artwork_uri(artist)
         else:
             return None
@@ -111,6 +119,8 @@ class Downloader:
             @param artist as str
             @return uri as str/None
         """
+        if not get_network_available("DEEZER"):
+            return None
         try:
             artist_formated = GLib.uri_escape_string(
                 artist, None, True).replace(" ", "+")
@@ -131,6 +141,8 @@ class Downloader:
             @param artist as str
             @return uri as str/None
         """
+        if not get_network_available("SPOTIFY"):
+            return None
         try:
             artist_formated = GLib.uri_escape_string(
                 artist, None, True).replace(" ", "+")
@@ -143,7 +155,8 @@ class Downloader:
             if status:
                 decode = json.loads(data.decode("utf-8"))
                 for item in decode["artists"]["items"]:
-                    if item["name"].lower() == artist.lower():
+                    if noaccents(item["name"].lower()) ==\
+                            noaccents(artist.lower()):
                         return item["images"][0]["url"]
         except Exception as e:
             Logger.debug("Downloader::_get_spotify_artist_artwork(): %s [%s]" %
@@ -158,6 +171,8 @@ class Downloader:
             @return image as bytes
             @tread safe
         """
+        if not get_network_available("DEEZER"):
+            return None
         image = None
         try:
             album_formated = GLib.uri_escape_string(album, None, True)
@@ -168,7 +183,8 @@ class Downloader:
                 decode = json.loads(data.decode("utf-8"))
                 uri = None
                 for item in decode["data"]:
-                    if item["artist"]["name"].lower() == artist.lower():
+                    if noaccents(item["artist"]["name"].lower()) ==\
+                            noaccents(artist.lower()):
                         uri = item["cover_xl"]
                         break
                 if uri is not None:
@@ -187,6 +203,8 @@ class Downloader:
             @return image as bytes
             @tread safe
         """
+        if not get_network_available("SPOTIFY"):
+            return None
         image = None
         artists_spotify_ids = []
         try:
@@ -212,7 +230,8 @@ class Downloader:
                     decode = json.loads(data.decode("utf-8"))
                     uri = None
                     for item in decode["items"]:
-                        if item["name"] == album:
+                        if noaccents(item["name"].lower()) ==\
+                                noaccents(album.lower()):
                             uri = item["images"][0]["url"]
                             break
                     if uri is not None:
@@ -232,6 +251,8 @@ class Downloader:
             @return image as bytes
             @tread safe
         """
+        if not get_network_available("ITUNES"):
+            return None
         image = None
         try:
             album_formated = GLib.uri_escape_string(
@@ -242,7 +263,8 @@ class Downloader:
             if status:
                 decode = json.loads(data.decode("utf-8"))
                 for item in decode["results"]:
-                    if item["artistName"].lower() == artist.lower():
+                    if noaccents(item["artistName"].lower()) ==\
+                            noaccents(artist.lower()):
                         uri = item["artworkUrl60"].replace("60x60",
                                                            "512x512")
                         (status,
@@ -262,6 +284,8 @@ class Downloader:
             @return data as bytes
             @tread safe
         """
+        if not get_network_available("LASTFM"):
+            return None
         image = None
         if App().lastfm is not None:
             try:
@@ -309,8 +333,7 @@ class Downloader:
         """
         # Then cache for lastfm/spotify/deezer/...
         for (artist_id, artist, sort) in App().artists.get([]):
-            if not get_network_available() or\
-                    InformationStore.artwork_exists(artist):
+            if InformationStore.artwork_exists(artist):
                 continue
             artwork_set = False
             for (api, helper, unused) in InformationStore.WEBSERVICES:
