@@ -44,6 +44,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         PlaylistPlayer.__init__(self)
         RadioPlayer.__init__(self)
         SimilarsPlayer.__init__(self)
+        self.__stop_after_track_id = None
         self.update_crossfading()
         App().settings.connect("changed::repeat", self.__on_repeat_changed)
         self._albums_backup = []
@@ -52,11 +53,13 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         """
             Play previous track
         """
-        if self._prev_track.id is not None:
-            if self.position / Gst.SECOND > 2:
-                self.seek(0)
-            else:
-                self.load(self._prev_track)
+        if App().window.toolbar.playback.seek_wanted:
+            self.seek(0)
+            self.emit("current-changed")
+            if not self.is_playing:
+                self.play()
+        elif self._prev_track.id is not None:
+            self.load(self._prev_track)
         else:
             self.stop()
 
@@ -321,6 +324,13 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         self.set_prev()
         self.emit("playlist-changed")
 
+    def stop_after(self, track_id):
+        """
+            Tell player to stop after track_id
+            @param track_id as int
+        """
+        self.__stop_after_track_id = track_id
+
     def get_current_artists(self):
         """
             Get current artist
@@ -430,7 +440,9 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             Play next track
             @param sql as sqlite cursor
         """
-        if self.current_track.id == Type.RADIOS:
+        if self.current_track.id == Type.RADIOS or\
+                self._current_track.id == self.__stop_after_track_id:
+            self._next_track = Track()
             return
         try:
             next_track = QueuePlayer.next(self)
@@ -530,6 +542,14 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         """
         return [album.id for album in self._albums]
 
+    @property
+    def stop_after_track_id(self):
+        """
+            Get stop after track id
+            @return int
+        """
+        return self.__stop_after_track_id
+
 #######################
 # PROTECTED           #
 #######################
