@@ -48,7 +48,6 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
         self._album_box.set_margin_start(MARGIN)
         self._album_box.set_margin_end(MARGIN)
         self.__set_artwork()
-        self._on_lock_changed(App().player)
 
     def jump_to_current(self):
         """
@@ -149,6 +148,7 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
             Connect signals and set active ids
             @param widget as Gtk.Widget
         """
+        self.__on_album_changed(App().player)
         if self.__show_artwork:
             self._album_box.set_margin_top(self._banner.default_height + 15)
         else:
@@ -166,9 +166,6 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
         self.__removed_signal_id = App().player.connect(
                                                   "album-removed",
                                                   self.__on_album_changed)
-        self.__lock_signal_id = App().player.connect(
-                                               "lock-changed",
-                                               self._on_lock_changed)
         App().settings.set_value("state-one-ids",
                                  GLib.Variant("ai", self._genre_ids))
         App().settings.set_value("state-two-ids",
@@ -191,9 +188,6 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
         if self.__removed_signal_id is not None:
             App().player.disconnect(self.__removed_signal_id)
             self.__removed_signal_id = None
-        if self.__lock_signal_id is not None:
-            App().player.disconnect(self.__lock_signal_id)
-            self.__lock_signal_id = None
 
 #######################
 # PRIVATE             #
